--#! /usr/bin/env love vilua.love
--
-- main.lua
--
-- Dirk Laurie, 2011
--
-- See also leading comments in vilua.lua

Ilua = require "vilua"
-- create an Ilua instance
ilua = Ilua:new(params)
function prompt(...)
   return ilua:run(...)
   end

basics = { 
   circle="( 'line'|'fill', x, y, radius [, segments=8] )", 
   point='( x, y )', 
   line='( { x1, y1, x2, y2, ...}  )', 
   rotate='( angle )', 
   translate='( dx, dy )', 
   scale='( sx, sy )',
   text='( text, x, y [, theta=0, sx=1, sy=sx] )',
   polygon="( 'line'|'fill', { x1, y1, x2, y2, ...} )",
   clear='()',
   setColor='( { red, green, blue, alpha } )',
   setFont='( [filename,] size )'
}

function love.load()
   love.graphics.setCaption('Lua with graphics')
   deg = math.pi/180
   black = {0,0,0};  gray = {100,100,100};     
   red = {255,0,0};  green = {0,255,0};  blue = {0,0,255}
   yellow = {255,255,0}; magenta = {255,0,255}; cyan = {0,255,255}
   background = black
   chunk = ''
   history = {}
   for k in pairs(basics) do _G[k] = love.graphics[k] end    
   _G.text = love.graphics.print
   ilua:start()
end

function drawable(chunk)
   return rawget(basics, chunk:match "^%s*(%w+)%s*%(")
   end

terminal = coroutine.wrap(prompt)

function signal_quit() love.event.push "q" end

function push(group,src,func)
   local item = { f=func; src=src }
   setmetatable (item, {__call = func})
   group[#group+1] = item
end

function showsource(group)
   for k=1,#group do
      io.write(k,'. ',group[k].src,'\n')
   end
end

function showkeys(group)
   for k,v in pairs(group) do io.write(string.format("%16s  %s\n",k,v))
   end
end

function love.update()
   terminal()
end

function love.draw()
   for k=1,#history do history[k]() end
end
